/// <reference types="node" />
import fs from 'fs';
type LogFunction = (ctx: any, msg: string) => void;
/**
 * Expected image file info
 */
export interface ImageInfo {
    kind: string;
    width: number;
    height: number;
    crop?: boolean;
}
/**
 * Generated image file info
 */
export interface OutImageInfo {
    kind: string;
    format: 'jpeg';
    width: number;
    height: number;
    filePath: string;
}
/**
 * sharp-mozjpeg-image-processor
 * main class
 */
export declare class ImageProcessor {
    private tmpRootDir;
    private log;
    /**
     * @param tmpDir temporary directory
     * @param log Logging function
     */
    constructor(tmpDir?: string, log?: LogFunction);
    /**
     * execute generating image files from source file stream
     *
     * @param fileStream source image file stream
     * @param imageInfos generating image file infos
     * @param quality jpeg quality 0~100
     * @returns generated image file infos
     */
    execute(fileStream: fs.ReadStream, imageInfos: ImageInfo[], quality?: number): Promise<OutImageInfo[]>;
    private generateArrangedFile;
    private generateScaledFile;
}
export {};
