"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertToScaledFile = exports.convertStreamToArrangedFile = void 0;
const fs_1 = __importDefault(require("fs"));
const sharp = require('sharp');
const promisedLifestream = require('promised-lifestream');
async function convertStreamToArrangedFile(srcFileStream, destFilePath, maxWidth, maxHeight) {
    let imgInfo = null;
    const largeResizer = sharp()
        .rotate()
        .resize(maxWidth, maxHeight, { fit: 'inside', withoutEnlargement: false })
        .on('info', (info) => { imgInfo = info; })
        .jpeg({ mozjpeg: true });
    const fileWriter = fs_1.default.createWriteStream(destFilePath, { encoding: undefined });
    await promisedLifestream([
        srcFileStream,
        largeResizer,
        fileWriter,
    ]);
    return imgInfo;
}
exports.convertStreamToArrangedFile = convertStreamToArrangedFile;
async function convertToScaledFile(srcFilePath, destFilePath, crop, maxWidth, maxHeight) {
    return sharp(srcFilePath)
        .resize({ width: maxWidth, height: maxHeight, fit: crop ? 'cover' : 'inside' })
        .jpeg({ mozjpeg: true })
        .toFile(destFilePath);
}
exports.convertToScaledFile = convertToScaledFile;
